@@ -6,6 +6,7 @@
 # See LICENSE.txt for details
 # -----------------------------------------------------------------------------
 """Nodes module for the pythonic interface to SWMM5."""
+from swmm.toolkit import shared_enum
 
 # Local imports
 from pyswmm.swmm5 import PYSWMMException
@@ -186,7 +187,7 @@ class Node(object):
         ...     print j1.is_junction()
         >>> True
         """
-        return self._model.getNodeType(self._nodeid) is NodeType.junction.value
+        return self._model.getNodeType(self._nodeid) is shared_enum.NodeType.JUNCTION
 
     def is_outfall(self):
         """
@@ -204,7 +205,7 @@ class Node(object):
         ...     print j1.is_outfall()
         >>> True
         """
-        return self._model.getNodeType(self._nodeid) is NodeType.outfall.value
+        return self._model.getNodeType(self._nodeid) is shared_enum.NodeType.OUTFALL
 
     def is_storage(self):
         """
@@ -222,7 +223,7 @@ class Node(object):
         ...     print j1.is_storage()
         >>> True
         """
-        return self._model.getNodeType(self._nodeid) is NodeType.storage.value
+        return self._model.getNodeType(self._nodeid) is shared_enum.NodeType.STORAGE
 
     def is_divider(self):
         """
@@ -240,7 +241,7 @@ class Node(object):
         ...     print j1.is_divider()
         >>> True
         """
-        return self._model.getNodeType(self._nodeid) is NodeType.divider.value
+        return self._model.getNodeType(self._nodeid) is shared_enum.NodeType.DIVIDER
 
     @property
     def invert_elevation(self):
@@ -679,11 +680,21 @@ class Node(object):
         """
         self._model.setNodeInflow(self._nodeid, inflowrate)
 
+    @property
+    def cumulative_inflow(self):
+        """
+        Get Cumulative Node Loading.
+
+        :return: Cumulative Volume
+        :rtype: float
+        """
+        value = self._model.node_inflow(self.nodeid)
+        return value
+
     @property
     def pollut_quality(self):
         """
         Get Current Water Quality Values for a Node.
-
         If Simulation is not running this method will raise a warning and
         return 0.
 
@@ -785,20 +796,6 @@ class Outfall(Node):
         """
         return self._model.outfall_statistics(self.nodeid)
 
-    @property
-    def cumulative_inflow(self):
-        """
-        Get Cumulative Outfall Loading.
-
-        If Simulation is not running this method will raise a warning and
-        return 0.
-
-        :return: Cumulative Volume
-        :rtype: float
-        """
-        value = self._model.node_inflow(self.nodeid)
-        return value
-
     def outfall_stage(self, stage):
         """
         Generate and Set an Outfall Stage (head).
